<?php
/**
 * Implement a custom header for WPstart.
 *
 * @link http://codex.wordpress.org/Custom_Headers
 *
 * @package WPstart
 */

/**
 * Set up the WordPress core custom header arguments and settings.
 */
function wpstart_custom_header_setup() {
	$args = array(
		'default-image'          => '%s/images/headers/default.png',
		'random-default'         => false,
		'width'                  => 1600,
		'height'                 => 80,
		'flex-height'            => false,
		'flex-width'             => false,
		'default-text-color'     => '000000',
		'header-text'            => true,
		'uploads'                => true,		
		'wp-head-callback'       => 'wpstart_header_style',
		'admin-head-callback'    => 'wpstart_admin_header_style',
		'admin-preview-callback' => 'wpstart_admin_header_image',
	);

	// Adds support for a custom header image.
	add_theme_support( 'custom-header', $args );

	/*
	 * Register a default header to be displayed by the custom header admin UI.
	 * The %s is replaced with theme template directory URI.
	 * To reference a image in a child theme (ie in the stylesheet directory), use %2$s instead of %s.
	 */
	register_default_headers( array(
		'default' => array(
			'url'           => '%s/images/headers/default.png',
			'thumbnail_url' => '%s/images/headers/default-thumbnail.png',
			'description'   => _x( 'Default', 'header image description', 'wpstart' )
		),
		'blue' => array(
			'url'           => '%s/images/headers/blue.png',
			'thumbnail_url' => '%s/images/headers/blue-thumbnail.png',
			'description'   => _x( 'Blue', 'header image description', 'wpstart' )
		),
		'brown' => array(
			'url'           => '%s/images/headers/brown.png',
			'thumbnail_url' => '%s/images/headers/brown-thumbnail.png',
			'description'   => _x( 'Brown', 'header image description', 'wpstart' )
		),
		'green' => array(
			'url'           => '%s/images/headers/green.png',
			'thumbnail_url' => '%s/images/headers/green-thumbnail.png',
			'description'   => _x( 'Green', 'header image description', 'wpstart' )
		),
		'orange' => array(
			'url'           => '%s/images/headers/orange.png',
			'thumbnail_url' => '%s/images/headers/orange-thumbnail.png',
			'description'   => _x( 'Orange', 'header image description', 'wpstart' )
		),
		'pink' => array(
			'url'           => '%s/images/headers/pink.png',
			'thumbnail_url' => '%s/images/headers/pink-thumbnail.png',
			'description'   => _x( 'Pink', 'header image description', 'wpstart' )
		),
		'purple' => array(
			'url'           => '%s/images/headers/purple.png',
			'thumbnail_url' => '%s/images/headers/purple-thumbnail.png',
			'description'   => _x( 'Purple', 'header image description', 'wpstart' )
		),
		'red' => array(
			'url'           => '%s/images/headers/red.png',
			'thumbnail_url' => '%s/images/headers/red-thumbnail.png',
			'description'   => _x( 'Red', 'header image description', 'wpstart' )
		),
		'silver' => array(
			'url'           => '%s/images/headers/silver.png',
			'thumbnail_url' => '%s/images/headers/silver-thumbnail.png',
			'description'   => _x( 'Silver', 'header image description', 'wpstart' )
		),
		'white' => array(
			'url'           => '%s/images/headers/white.png',
			'thumbnail_url' => '%s/images/headers/white-thumbnail.png',
			'description'   => _x( 'White', 'header image description', 'wpstart' )
		),
		'yellow' => array(
			'url'           => '%s/images/headers/yellow.png',
			'thumbnail_url' => '%s/images/headers/yellow-thumbnail.png',
			'description'   => _x( 'Yellow', 'header image description', 'wpstart' )
		),
	) );
}
add_action( 'after_setup_theme', 'wpstart_custom_header_setup' );

/**
 * Styles the header displayed on front-end.
 */
if ( !function_exists( 'wpstart_header_style' ) ) {
	function wpstart_header_style() {
		$header_image = get_header_image();
		$header_textcolor = get_header_textcolor();
		
		// If header image is not set and header text color is set to default (no custom options are set), let's bail.
		// Header text color is then shown from style.css settings.
		if ( empty( $header_image ) && $header_textcolor == get_theme_support( 'custom-header', 'default-text-color' ) )
			return;
		?>
		<style type="text/css" id="wpstart-header-style">
		<?php
			// If custom header is set.
			if ( ! empty( $header_image ) ) :
		?>
			.site-header {
				background: url(<?php header_image(); ?>) no-repeat scroll top;
				background-size: 1600px auto;
				min-height: 80px;
			}
		<?php
			endif;
			
			if ( empty( $header_image ) ) : ?>
			#header hgroup {
				margin-top :0;
				min-height: 0;
			}
		<?php
			endif;
			
			// If there is no header text.
			if ( ! display_header_text() ) :
		?>
			.site-title,
			.site-title a:link,
			.site-title a:visited,
			.site-description {
				position: absolute;
				clip: rect(1px, 1px, 1px, 1px);
			}
		<?php
			endif;

			// If is set a custom color for the header text.
			if ( ! empty( $header_textcolor ) ) :
		?>
			.site-title a:link,
			.site-title a:visited,
			.site-title a:hover,
			.site-title a:active,
			.site-description {
				color: #<?php echo esc_attr( $header_textcolor ); ?>;
			}
		<?php endif; ?>
		</style>
	<?php
	}
}

/**
 * Add custom styles to header image displayed on the Appearance > Header admin panel.
 */
if ( !function_exists( 'wpstart_admin_header_style' ) ) {
	function wpstart_admin_header_style() { 
		$header_image = get_header_image();
		$header_textcolor = get_header_textcolor();		
		?>
		
		<style type="text/css" id="wpstart-admin-header-style">
		#header hgroup {
		<?php
		if ( ! empty( $header_image ) || display_header_text() ) : ?>
			min-height: 60px;
			margin-top: 20px;
		<?php endif; ?>
		}
		
		.site-title {
			color: #<?php echo esc_attr( $header_textcolor ); ?>;
			font-size: 36px;
			line-height: 1;
			margin: 0;
			font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
		}

		.site-title a:link,
		.site-title a:visited {
			color: #<?php echo esc_attr( $header_textcolor ); ?>;
			text-decoration: none;
		}

		.site-title a:hover,
		.site-title a:active {
			color: #<?php echo esc_attr( $header_textcolor ); ?>;
			text-decoration: none;
		}
		
		.site-description,
		h2.site-description {
			color: #<?php echo esc_attr( $header_textcolor ); ?>;
			font-size: 14px;
			line-height: 1;
			margin: 0 0 10px;
			padding: 0;
			font-family: "Helvetica Neue", Helvetica, Arial, sans-serif; 
		}
		
		<?php if ( ! display_header_text() ) : ?>
		.site-title,
		.site-description {
			position: absolute !important;
			clip: rect(1px, 1px, 1px, 1px);
		}
		<?php endif; ?>

		@media screen and (min-width: 768px) {
			/* Header */
			#header hgroup {
				float: left;
			}
		}
		
		@media screen and (max-width: 767px) {
			#header hgroup {
				float: left;
			}
		}
		
		.appearance_page_custom-header #header {
			-webkit-box-sizing: border-box;
			-moz-box-sizing:    border-box;
			box-sizing:         border-box;
			<?php
			if ( ! empty( $header_image ) ) {
				echo 'background: url(' . esc_url( $header_image ) . ') no-repeat scroll top; background-size: 1600px auto;';
			} ?>
		}
		
		.container {
			margin-left: auto;
			margin-right: auto;
			padding-left: 15px;
			padding-right: 15px;
		}

		.container:before,
		.container:after {
			content: " ";
			display: table;
		}

		.container:after {
			clear: both;
		}
		</style>
	<?php 
	}
}

/**
 * Add custom markup to header image displayed on the Appearance > Header admin panel.
 */
if ( !function_exists( 'wpstart_admin_header_image' ) ) {
	function wpstart_admin_header_image() { ?>
		<header id="header" class="site-header" role="banner">
			<div class="container">
				<hgroup>
					<h1 class="site-title">
						<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>"><?php bloginfo( 'name' ); ?></a>
					</h1>
					<?php $site_description = get_bloginfo('description');
					if ( ! empty( $site_description ) ) : ?>		
					<h2 class="site-description"><?php bloginfo('description'); ?></h2>
					<?php endif; ?>
				</hgroup>
			</div><!-- .container -->
		</header><!-- #header -->
	<?php 
	}
}